@@ -16,6 +16,7 @@
 # $Revision: 10369 $
 
 from django.conf.urls import url, include, patterns
+from newsletter_extension import views as newsletterExtensionViews 
 
 import views
 
@@ -57,5 +58,5 @@ urlpatterns = patterns('',
 
     # resend error contact.
     url(r'^newsletters/resend/(?P<newsletterId>\w+)',
-        views.resendErrorContact, name='resendErrorContact'),
+        newsletterExtensionViews.resendErrorContact, name='resendErrorContact'),
 )
